;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "evil-nerd-commenter" "20260507.414"
  "Comment/uncomment lines efficiently. Like Nerd Commenter in Vim."
  '((emacs "26.1"))
  :url "https://github.com/redguardtoo/evil-nerd-commenter"
  :commit "db5ee61a6e75db074b7d20e9dcb68e0b94b4edc7"
  :revdesc "db5ee61a6e75"
  :keywords '("convenience" "evil")
  :authors '(("Chen Bin" . "chenbin.sh@gmail.com"))
  :maintainers '(("Chen Bin" . "chenbin.sh@gmail.com")))
